#ifndef NT2_INCLUDE_FUNCTIONS_IS_TRUE_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_IS_TRUE_HPP_INCLUDED

#include <nt2/predicates/include/functions/is_true.hpp>

#endif
